==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/MigrateSqlServerSqlMISyncTaskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.MigrateSqlServerSqlMISyncTaskInputArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Input for task that migrates SQL Server databases to Azure SQL Database Managed Instance online scenario.
 * @property azureApp Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
 * @property backupFileShare Backup file share information for all selected databases.
 * @property selectedDatabases Databases to migrate
 * @property sourceConnectionInfo Connection information for source SQL Server
 * @property storageResourceId Fully qualified resourceId of storage
 * @property targetConnectionInfo Connection information for Azure SQL Database Managed Instance
 */
public data class MigrateSqlServerSqlMISyncTaskInputArgs(
    public val azureApp: Output<AzureActiveDirectoryAppArgs>,
    public val backupFileShare: Output<FileShareArgs>? = null,
    public val selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>,
    public val sourceConnectionInfo: Output<SqlConnectionInfoArgs>,
    public val storageResourceId: Output<String>,
    public val targetConnectionInfo: Output<MiSqlConnectionInfoArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.MigrateSqlServerSqlMISyncTaskInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.MigrateSqlServerSqlMISyncTaskInputArgs =
        com.pulumi.azurenative.datamigration.inputs.MigrateSqlServerSqlMISyncTaskInputArgs.builder()
            .azureApp(azureApp.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .backupFileShare(backupFileShare?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .selectedDatabases(
                selectedDatabases.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .sourceConnectionInfo(
                sourceConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .storageResourceId(storageResourceId.applyValue({ args0 -> args0 }))
            .targetConnectionInfo(
                targetConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [MigrateSqlServerSqlMISyncTaskInputArgs].
 */
@PulumiTagMarker
public class MigrateSqlServerSqlMISyncTaskInputArgsBuilder internal constructor() {
    private var azureApp: Output<AzureActiveDirectoryAppArgs>? = null

    private var backupFileShare: Output<FileShareArgs>? = null

    private var selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>? = null

    private var sourceConnectionInfo: Output<SqlConnectionInfoArgs>? = null

    private var storageResourceId: Output<String>? = null

    private var targetConnectionInfo: Output<MiSqlConnectionInfoArgs>? = null

    /**
     * @param value Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("mmjytnflugqjfrhj")
    public suspend fun azureApp(`value`: Output<AzureActiveDirectoryAppArgs>) {
        this.azureApp = value
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("iiafyrmyvgxnrdhu")
    public suspend fun backupFileShare(`value`: Output<FileShareArgs>) {
        this.backupFileShare = value
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("mclqrbecwrqvejww")
    public suspend
    fun selectedDatabases(`value`: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = value
    }

    @JvmName("ntvkeautpbjnmtoc")
    public suspend fun selectedDatabases(
        vararg
        values: Output<MigrateSqlServerSqlMIDatabaseInputArgs>,
    ) {
        this.selectedDatabases = Output.all(values.asList())
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("upnfbgbmpunjvrid")
    public suspend
    fun selectedDatabases(values: List<Output<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = Output.all(values)
    }

    /**
     * @param value Connection information for source SQL Server
     */
    @JvmName("gbqpaaluvdgismpa")
    public suspend fun sourceConnectionInfo(`value`: Output<SqlConnectionInfoArgs>) {
        this.sourceConnectionInfo = value
    }

    /**
     * @param value Fully qualified resourceId of storage
     */
    @JvmName("atcqhupikbhdhjpr")
    public suspend fun storageResourceId(`value`: Output<String>) {
        this.storageResourceId = value
    }

    /**
     * @param value Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("bnjiftpahaqbupmh")
    public suspend fun targetConnectionInfo(`value`: Output<MiSqlConnectionInfoArgs>) {
        this.targetConnectionInfo = value
    }

    /**
     * @param value Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("pnousliovahwbuow")
    public suspend fun azureApp(`value`: AzureActiveDirectoryAppArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureApp = mapped
    }

    /**
     * @param argument Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("ofbceljuysxelwpb")
    public suspend fun azureApp(argument: suspend AzureActiveDirectoryAppArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryAppArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureApp = mapped
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("nhdfpferytsfeqos")
    public suspend fun backupFileShare(`value`: FileShareArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupFileShare = mapped
    }

    /**
     * @param argument Backup file share information for all selected databases.
     */
    @JvmName("tulvruxlhngryifp")
    public suspend fun backupFileShare(argument: suspend FileShareArgsBuilder.() -> Unit) {
        val toBeMapped = FileShareArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.backupFileShare = mapped
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("hwhrxrjklpukwlhq")
    public suspend fun selectedDatabases(`value`: List<MigrateSqlServerSqlMIDatabaseInputArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("qotvjhkpqyfymxyi")
    public suspend
    fun selectedDatabases(argument: List<suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("gxunltprskaylhlo")
    public suspend fun selectedDatabases(
        vararg
        argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("dhoemdefcqqxgtpa")
    public suspend
    fun selectedDatabases(argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("kucwbeypbofjfhxe")
    public suspend fun selectedDatabases(vararg values: MigrateSqlServerSqlMIDatabaseInputArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param value Connection information for source SQL Server
     */
    @JvmName("rmafjoqwslcwwvpn")
    public suspend fun sourceConnectionInfo(`value`: SqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param argument Connection information for source SQL Server
     */
    @JvmName("enoilyqneegsxvyg")
    public suspend
    fun sourceConnectionInfo(argument: suspend SqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = SqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param value Fully qualified resourceId of storage
     */
    @JvmName("jdqqpxpmkgrcqaih")
    public suspend fun storageResourceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageResourceId = mapped
    }

    /**
     * @param value Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("fgnsqafxvdsvmnqm")
    public suspend fun targetConnectionInfo(`value`: MiSqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetConnectionInfo = mapped
    }

    /**
     * @param argument Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("osqilxtdgaqclgxf")
    public suspend
    fun targetConnectionInfo(argument: suspend MiSqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = MiSqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.targetConnectionInfo = mapped
    }

    internal fun build(): MigrateSqlServerSqlMISyncTaskInputArgs =
        MigrateSqlServerSqlMISyncTaskInputArgs(
            azureApp = azureApp ?: throw PulumiNullFieldException("azureApp"),
            backupFileShare = backupFileShare,
            selectedDatabases = selectedDatabases ?: throw PulumiNullFieldException("selectedDatabases"),
            sourceConnectionInfo = sourceConnectionInfo ?: throw
                PulumiNullFieldException("sourceConnectionInfo"),
            storageResourceId = storageResourceId ?: throw PulumiNullFieldException("storageResourceId"),
            targetConnectionInfo = targetConnectionInfo ?: throw
                PulumiNullFieldException("targetConnectionInfo"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/MigrateSqlServerSqlMISyncTaskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.MigrateSqlServerSqlMISyncTaskInputArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Input for task that migrates SQL Server databases to Azure SQL Database Managed Instance online scenario.
 * @property azureApp Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
 * @property backupFileShare Backup file share information for all selected databases.
 * @property selectedDatabases Databases to migrate
 * @property sourceConnectionInfo Connection information for source SQL Server
 * @property storageResourceId Fully qualified resourceId of storage
 * @property targetConnectionInfo Connection information for Azure SQL Database Managed Instance
 */
public data class MigrateSqlServerSqlMISyncTaskInputArgs(
    public val azureApp: Output<AzureActiveDirectoryAppArgs>,
    public val backupFileShare: Output<FileShareArgs>? = null,
    public val selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>,
    public val sourceConnectionInfo: Output<SqlConnectionInfoArgs>,
    public val storageResourceId: Output<String>,
    public val targetConnectionInfo: Output<MiSqlConnectionInfoArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.MigrateSqlServerSqlMISyncTaskInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.MigrateSqlServerSqlMISyncTaskInputArgs =
        com.pulumi.azurenative.datamigration.inputs.MigrateSqlServerSqlMISyncTaskInputArgs.builder()
            .azureApp(azureApp.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .backupFileShare(backupFileShare?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .selectedDatabases(
                selectedDatabases.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .sourceConnectionInfo(
                sourceConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .storageResourceId(storageResourceId.applyValue({ args0 -> args0 }))
            .targetConnectionInfo(
                targetConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [MigrateSqlServerSqlMISyncTaskInputArgs].
 */
@PulumiTagMarker
public class MigrateSqlServerSqlMISyncTaskInputArgsBuilder internal constructor() {
    private var azureApp: Output<AzureActiveDirectoryAppArgs>? = null

    private var backupFileShare: Output<FileShareArgs>? = null

    private var selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>? = null

    private var sourceConnectionInfo: Output<SqlConnectionInfoArgs>? = null

    private var storageResourceId: Output<String>? = null

    private var targetConnectionInfo: Output<MiSqlConnectionInfoArgs>? = null

    /**
     * @param value Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("rbkfyruafjeqvbof")
    public suspend fun azureApp(`value`: Output<AzureActiveDirectoryAppArgs>) {
        this.azureApp = value
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("unomgbhmooatmwbm")
    public suspend fun backupFileShare(`value`: Output<FileShareArgs>) {
        this.backupFileShare = value
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("xopyevwdlrkeqyay")
    public suspend
    fun selectedDatabases(`value`: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = value
    }

    @JvmName("kvsovmcdmosibwkh")
    public suspend fun selectedDatabases(
        vararg
        values: Output<MigrateSqlServerSqlMIDatabaseInputArgs>,
    ) {
        this.selectedDatabases = Output.all(values.asList())
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("opywoihomahxsufe")
    public suspend
    fun selectedDatabases(values: List<Output<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = Output.all(values)
    }

    /**
     * @param value Connection information for source SQL Server
     */
    @JvmName("qjlupciqlgocrglq")
    public suspend fun sourceConnectionInfo(`value`: Output<SqlConnectionInfoArgs>) {
        this.sourceConnectionInfo = value
    }

    /**
     * @param value Fully qualified resourceId of storage
     */
    @JvmName("loljxeeuflerpvqv")
    public suspend fun storageResourceId(`value`: Output<String>) {
        this.storageResourceId = value
    }

    /**
     * @param value Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("jnnlnpaenbixpegh")
    public suspend fun targetConnectionInfo(`value`: Output<MiSqlConnectionInfoArgs>) {
        this.targetConnectionInfo = value
    }

    /**
     * @param value Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("ilkbregwwsuouvqc")
    public suspend fun azureApp(`value`: AzureActiveDirectoryAppArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureApp = mapped
    }

    /**
     * @param argument Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("bswskwtqufrkkpsx")
    public suspend fun azureApp(argument: suspend AzureActiveDirectoryAppArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryAppArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureApp = mapped
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("aiqwhaogegulcoti")
    public suspend fun backupFileShare(`value`: FileShareArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupFileShare = mapped
    }

    /**
     * @param argument Backup file share information for all selected databases.
     */
    @JvmName("xcivixhreicuqwao")
    public suspend fun backupFileShare(argument: suspend FileShareArgsBuilder.() -> Unit) {
        val toBeMapped = FileShareArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.backupFileShare = mapped
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("tvsmhvgcexgetton")
    public suspend fun selectedDatabases(`value`: List<MigrateSqlServerSqlMIDatabaseInputArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("rnqpjbqdbjswhsoj")
    public suspend
    fun selectedDatabases(argument: List<suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("fgppppkorspiuwjc")
    public suspend fun selectedDatabases(
        vararg
        argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("pncgnawqoklrvqpx")
    public suspend
    fun selectedDatabases(argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("lgxkaunvttibcrpw")
    public suspend fun selectedDatabases(vararg values: MigrateSqlServerSqlMIDatabaseInputArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param value Connection information for source SQL Server
     */
    @JvmName("hpfukqpfdatkjngl")
    public suspend fun sourceConnectionInfo(`value`: SqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param argument Connection information for source SQL Server
     */
    @JvmName("icniowahnotlnaxf")
    public suspend
    fun sourceConnectionInfo(argument: suspend SqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = SqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param value Fully qualified resourceId of storage
     */
    @JvmName("seqwemcmpipomgrq")
    public suspend fun storageResourceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageResourceId = mapped
    }

    /**
     * @param value Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("ttmuapyihhqqhylu")
    public suspend fun targetConnectionInfo(`value`: MiSqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetConnectionInfo = mapped
    }

    /**
     * @param argument Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("wfgulgaqssfcyvuv")
    public suspend
    fun targetConnectionInfo(argument: suspend MiSqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = MiSqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.targetConnectionInfo = mapped
    }

    internal fun build(): MigrateSqlServerSqlMISyncTaskInputArgs =
        MigrateSqlServerSqlMISyncTaskInputArgs(
            azureApp = azureApp ?: throw PulumiNullFieldException("azureApp"),
            backupFileShare = backupFileShare,
            selectedDatabases = selectedDatabases ?: throw PulumiNullFieldException("selectedDatabases"),
            sourceConnectionInfo = sourceConnectionInfo ?: throw
                PulumiNullFieldException("sourceConnectionInfo"),
            storageResourceId = storageResourceId ?: throw PulumiNullFieldException("storageResourceId"),
            targetConnectionInfo = targetConnectionInfo ?: throw
                PulumiNullFieldException("targetConnectionInfo"),
        )
}
